@@ -99,6 +99,7 @@ my %options_spec = (
 			 $options{buildrequires} = 1 },
 	'buildrequires' => \$options{buildrequires},
 	'install-src' => \$::install_src,
+	reinstall => sub { $urpm->{options}{reinstall} = 1 },
 	clean => sub { $::clean = 1; $::noclean = 0 },
 	noclean => sub {
 	    $::clean = $urpm->{options}{'pre-clean'} = $urpm->{options}{'post-clean'} = 0;
@@ -269,7 +270,6 @@ my %options_spec = (
 	    $options{recommends} = 1;
 	},
 	suggests => sub { 
-	    $urpm->{error}("--suggests now displays the suggested packages, see --allow-suggests for previous behaviour");
 	    $urpm->{error}("You should now use --recommends.");
 	    $options{recommends} = 1;
 	},
@@ -284,10 +284,7 @@ my %options_spec = (
 	force => \$options{force},
 	'parallel=s' => \$options{parallel},
 	'env=s' => \$options{env},
-	requires => sub {
-	    $urpm->{error}("--requires behaviour changed, use --requires-recursive to get the old behaviour");
-	    $options{requires} = 1;
-	},
+	requires => sub { $options{requires} = 1 },
 	'requires-recursive|d' => \$options{deps},
 	u => \$options{upgrade},
 	a => \$options{all},
@@ -366,6 +363,7 @@ my %options_spec = (
 	nopubkey => \$options{nopubkey},
 	raw => \$options{raw},
 	'verify-rpm!' => sub { ${options}{'verify-rpm'} = $_[1] },
+	'ignorearch' => sub { $options{ignorearch} = 1 },
     },
 
 );
@@ -553,6 +551,8 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =for vim:ts=8:sts=4:sw=4
 
 =cut
